<?php
/* ----------------------
			MASTER
   ----------------------  */

// Defines functions to set sharing options on posttypes. Currently this is only applicable to the master account, i.e GOI

add_action( 'add_meta_boxes', 'gulf_sharing_meta_box_add' );
function gulf_sharing_meta_box_add() {
	global $sharedposttypes;
    add_meta_box( 'gulf-sharing', 'Content sharing', 'gulf_sharing_meta_box_cb', $sharedposttypes, 'side', 'default' );
}

function gulf_sharing_meta_box_cb($post) {
	$values = get_post_custom( $post->ID );
	
	$share = isset( $values['gulf_sharing_share'] ) ? esc_attr( $values['gulf_sharing_share'][0] ) : "none";
	$priv = isset( $values['gulf_sharing_privileges'] ) ? esc_attr( $values['gulf_sharing_privileges'][0] ) : "locked";
	
	wp_nonce_field( 'gulf_sharing_meta_box_nonce', 'meta_box_nonce' );
	?>
	<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="gulf_sharing_share">Sharing</label></p>
	<select name="gulf_sharing_share" id="gulf_sharing_share">
		<option value="none" <?php selected( $share, 'none' ); ?>><?php print __('No sharing') ?></option>
		<option value="all" <?php selected( $share, 'all' ); ?>><?php print __('Share with all') ?></option>
	</select>
	<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="gulf_sharing_privileges">Privileges</label></p>
	<select name="gulf_sharing_privileges" id="gulf_sharing_privileges">
		<option value="translatable" <?php selected( $priv, 'translatable' ); ?>><?php print __('Translatable') ?></option>
		<option value="locked" <?php selected( $priv, 'locked' ); ?>><?php print __('Locked') ?></option>
	</select>
	<?php
}


add_action( 'save_post', 'gulf_sharing_meta_box_save' );
function gulf_sharing_meta_box_save( $post_id ) {
    // Bail if we're doing an auto save
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
     
    // if our nonce isn't there, or we can't verify it, bail
    if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'gulf_sharing_meta_box_nonce' ) ) return;
     
    // if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post' ) ) return;
	
	if( isset( $_POST['gulf_sharing_share'] ) ) {
        update_post_meta( $post_id, 'gulf_sharing_share', esc_attr( $_POST['gulf_sharing_share'] ) );
	}

	if( isset( $_POST['gulf_sharing_privileges'] ) ) {
        update_post_meta( $post_id, 'gulf_sharing_privileges', esc_attr( $_POST['gulf_sharing_privileges'] ) );
	}
}

add_filter('manage_posts_columns', 'gulf_sharing_add_column', 10, 2); 
function gulf_sharing_add_column($posts_columns, $post_type) {
	global $sharedposttypes;
	if (in_array($post_type,$sharedposttypes)) {
	    $posts_columns['sharing'] = 'Sharing';
	}
    return $posts_columns;
}



add_action( 'bulk_edit_custom_box', 'gulf_sharing_bulk_edit', 10, 2 );
add_action( 'save_post', 'gulf_sharing_bulk_save', 10, 2 );
function gulf_sharing_bulk_edit($column_name, $post_type) {
	remove_action( 'bulk_edit_custom_box', 'gulf_sharing_bulk_edit', 10);
	?>
	<fieldset class="inline-edit-col-right">
		<div id="gulf-sharing-fields-bulk" class="inline-edit-col">

			<h4><?php _e( 'Content sharing', 'woocommerce' ); ?></h4>

			<div class="inline-edit-group">
				<label class="alignleft">
					<span class="title"><?php _e( 'Sharing', 'woocommerce' ); ?></span>
					<span class="input-text-wrap">
						<select class="gulf_sharing_share_change change_to" name="gulf_sharing_share">
							<option value=""><?php print __('— No Change —') ?></option>
							<option value="none"><?php print __('No sharing') ?></option>
							<option value="all"><?php print __('Share with all') ?></option>
						</select>
					</span>
				</label>
			</div>

			<div class="inline-edit-group">
				<label class="alignleft">
					<span class="title"><?php _e( 'Privileges', 'woocommerce' ); ?></span>
					<span class="input-text-wrap">
						<select class="gulf_sharing_privileges_change change_to" name="gulf_sharing_privileges">
							<option value=""><?php print __('— No Change —') ?></option>
							<option value="translatable"><?php print __('Translatable') ?></option>
							<option value="locked"><?php print __('Locked') ?></option>
						</select>
					</span>
				</label>
			</div>
			
			<input type="hidden" name="gulf_sharing_bulk_edit" value="1" />
			<input type="hidden" name="gulf_sharing_bulk_edit_nonce" value="<?php echo wp_create_nonce( 'gulf_sharing_bulk_edit_nonce' ); ?>" />			
		</div>
	</fieldset>			
	<?php
}

function gulf_sharing_bulk_save( $post_id, $post ) {

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}
	
	// Don't save revisions and autosaves
	if ( wp_is_post_revision( $post_id ) || wp_is_post_autosave( $post_id ) ) {
		return $post_id;
	}

	if ( isset( $_REQUEST['gulf_sharing_bulk_edit_nonce'] ) && ! wp_verify_nonce( $_REQUEST['gulf_sharing_bulk_edit_nonce'], 'gulf_sharing_bulk_edit_nonce' ) ) {
		return $post_id;
	}

	if ( isset( $_REQUEST['gulf_sharing_share'] ) ) {
		update_post_meta( $post_id, 'gulf_sharing_share', esc_attr( $_REQUEST['gulf_sharing_share'] ) );
	}
	
	if( isset( $_REQUEST['gulf_sharing_privileges'] ) ) {
        update_post_meta( $post_id, 'gulf_sharing_privileges', esc_attr( $_REQUEST['gulf_sharing_privileges'] ) );
	}
		
}


add_action( 'wp_ajax_create_uuids', 'gulf_create_uuids' );
function gulf_create_uuids() {
	global $wpdb;
	
	// Posts
	$objects = $wpdb->get_results('SELECT ID FROM wp_posts');
	foreach ($objects as $object) {
		$uuid = get_post_meta($object->ID,'uuid',true);
		if (empty($uuid)) {
			$uuid = $wpdb->get_var('SELECT UUID();');
			update_post_meta($object->ID,'uuid',$uuid);
		}
	}
	
	// Terms
	$terms = $wpdb->get_results('SELECT term_id FROM wp_terms');
	foreach ($terms as $term) {
		$uuid = get_term_meta($term->term_id,'uuid');
		if (empty($uuid)) {
			$uuid = $wpdb->get_var('SELECT UUID();');
			update_term_meta($term->term_id,'uuid',$uuid);
		}
	}
	
	
}


